@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.005_03';
+our $VERSION = '0.005_04';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -20,6 +20,9 @@ use Sort::Versions;
 use List::MoreUtils qw/uniq first_index/;
 use ExtUtils::Installed;
 use File::Copy qw/move/;
+use Env qw( @PATH );
+use Shell::Guess;
+use Shell::Config::Generate;
 
 use Alien::Base::PkgConfig;
 use Alien::Base::ModuleBuild::Cabinet;
@@ -111,6 +114,12 @@ __PACKAGE__->add_property( 'alien_autoconf_with_pic' => 1 );
 # alien_inline_auto_include
 __PACKAGE__->add_property( 'alien_inline_auto_include' => [] );
 
+# use MSYS even if %c isn't found
+__PACKAGE__->add_property( 'alien_msys' => 0 );
+
+# Alien packages that provide build dependencies
+__PACKAGE__->add_property( 'alien_bin_requires' => {} );
+
 ################
 #  ConfigData  #
 ################
@@ -149,12 +158,17 @@ sub new {
     $self->config_data( 'autoconf' => 1 );
   }
 
-  if ($^O eq 'MSWin32' && $self->config_data( 'autoconf')) {
+  if ($^O eq 'MSWin32' && ($self->config_data( 'autoconf') || $self->alien_msys)) {
     $self->_add_prereq( 'build_requires', 'Alien::MSYS', '0' );
     $self->config_data( 'msys' => 1 );
   } else {
     $self->config_data( 'msys' => 0 );
   }
+  
+  while(my($tool, $version) = each %{ $self->alien_bin_requires }) {
+    $self->_add_prereq( 'build_requires', $tool, $version );
+  }
+
 
   # force newest for all automated testing 
   #TODO (this probably should be checked for "input needed" rather than blindly assigned)
@@ -514,13 +528,59 @@ sub alien_detect_blib_scheme {
 #  Build Methods  #
 ###################
 
-sub _msys_do_system {
+sub _env_do_system {
   my $self = shift;
   my $command = shift;
   
+  local $ENV{PATH} = $ENV{PATH};
+  
   if ($self->config_data( 'msys' )) {
-    require Alien::MSYS;
-    return Alien::MSYS::msys(sub { $self->do_system( $command ) });
+    $self->alien_bin_requires->{'Alien::MSYS'} ||= 0
+  }
+  
+  foreach my $mod (keys %{ $self->alien_bin_requires }) {
+    my $version = $self->alien_bin_requires->{$mod};
+    eval qq{ use $mod $version () }; # should also work for version = 0
+    die $@ if $@;
+    
+    my %path;
+    
+    if ($mod eq 'Alien::MSYS') {
+      $path{Alien::MSYS->msys_path} = 1;
+    } elsif ($mod eq 'Alien::CMake') {
+      Alien::CMake->set_path;
+    } elsif ($mod eq 'Alien::TinyCC') {
+      $path{Alien::TinyCC->path_to_tcc} = 1;
+    } elsif ($mod eq 'Alien::Autotools') {
+      $path{$_} = 1 for map { Alien::Autotools->$_ } qw( autoconf_dir automake_dir libtool_dir );
+    } elsif (eval { $mod->can('bin_dir') }) {
+      $path{$_} = 1 for $mod->bin_dir;
+    }
+    
+    # remove anything already in PATH
+    delete $path{$_} for @PATH;
+    # add anything else to start of PATH
+    unshift @PATH, sort keys %path;
+
+    my $config = Shell::Config::Generate->new;
+    $config->comment(
+      'this script sets the environment needed to build this package.',
+      'generated by: ' . __FILE__,
+    );
+    $config->prepend_path( PATH => sort keys %path );
+    if($^O eq 'MSWin32') {
+      local $CWD;
+      pop @CWD;
+      $config->generate_file( Shell::Guess->command_shell, 'env.bat' );
+      $config->generate_file( Shell::Guess->cmd_shell,     'env.cmd' );
+      $config->generate_file( Shell::Guess->power_shell,   'env.ps1' );
+    } else {
+      local $CWD;
+      pop @CWD;
+      $config->generate_file( Shell::Guess->bourne_shell,  'env.sh'  );
+      $config->generate_file( Shell::Guess->c_shell,       'env.csh' );
+    }
+
   }
   
   $self->do_system( $command );
@@ -535,7 +595,7 @@ sub alien_do_commands {
 
   foreach my $command (@$commands) {
 
-    my %result = $self->_msys_do_system( $command );
+    my %result = $self->_env_do_system( $command );
     unless ($result{success}) {
       carp "External command ($result{command}) failed! Error: $?\n";
       return 0;
@@ -768,8 +828,6 @@ sub alien_find_lib_paths {
         next unless grep { $file eq $_ } @libs;
       }
       
-      $DB::single = 1;
-      
       next if grep { $file eq $_ } @lib_files;
 
       push @lib_files, $file;
